use bevy::{input::ButtonState, prelude::*};
use lib::{ItemPosition, Menu, MenuItemType, Menus, OnPressAction};

use crate::AppState;

mod lib;

#[derive(States, Debug, Copy, Clone, PartialEq, Eq, Hash, Default, Reflect)]
pub enum CurrentMenu {
    NotInMenus,
    #[default]
    MainMenu,
    Settings,
    HighScores,
    StartGame,
}
pub fn plugin(app: &mut App) {
    let plugin = Menus::<AppState, CurrentMenu>::new(AppState::Menus)
        .add_menu(
            CurrentMenu::MainMenu,
            Menu::new().add_items(&[
                &MenuItemType::Text(String::from("Hello, World!")),
                &(
                    MenuItemType::Button(String::from("Start Game")),
                    OnPressAction::SampleAction,
                ),
                &(
                    MenuItemType::Button(String::from("Settings")),
                    OnPressAction::NavigateTo(CurrentMenu::Settings),
                ),
            ]),
        )
        .add_menu(
            CurrentMenu::Settings,
            Menu::new()
                .add_items(&[
                    &MenuItemType::Text(String::from("Settings")),
                    &(
                        MenuItemType::Button(String::from("Sample setting")),
                        OnPressAction::SampleAction,
                    ),
                ])
                .add_items_positioned(
                    ItemPosition::SouthEast,
                    &[&(
                        MenuItemType::Button(String::from("Back")),
                        OnPressAction::NavigateTo(CurrentMenu::MainMenu),
                    )],
                ),
        );

    dbg!(&plugin);
    app.add_plugins(plugin);
}
